@@ -10,6 +10,9 @@ from _spotify import Link
 from _spotify import Results
 from _spotify import Playlist
 from _spotify import PlaylistContainer
+from _spotify import AlbumBrowser
+from _spotify import ArtistBrowser
+from _spotify import Image
 
 from _spotify import api_version
-from _spotify import connect
\ No newline at end of file
+from _spotify import connect
