@@ -4,7 +4,7 @@
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at 
+ * You may obtain a copy of the License at
  *
  *  http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -17,12 +17,15 @@
 
 #include <Python.h>
 #include <structmember.h>
-#include "spotify/api.h"
+#include "libspotify/api.h"
 #include "pyspotify.h"
 #include "artist.h"
+#include "artistbrowser.h"
 #include "album.h"
+#include "albumbrowser.h"
 #include "link.h"
 #include "playlist.h"
+#include "playlistcontainer.h"
 #include "search.h"
 #include "session.h"
 #include "track.h"
@@ -32,39 +35,43 @@ PyObject *SpotifyError;
 PyObject *SpotifyApiVersion;
 
 static PyMethodDef module_methods[] = {
-    {"connect", session_connect, METH_VARARGS, "Run the spotify subsystem.  this will return on error, or after spotify is logged out."},
+    {"connect", session_connect, METH_VARARGS,
+     "Run the spotify subsystem.  this will return on error, or after spotify is logged out."},
     {NULL, NULL, 0, NULL}
 };
 
-PyMODINIT_FUNC init_spotify(void) {
+PyMODINIT_FUNC
+init_spotify(void)
+{
     PyObject *m;
 
-    if(PyType_Ready(&SessionType) < 0)
-	return;
-    if(PyType_Ready(&AlbumType) < 0)
-	return;
-    if(PyType_Ready(&ArtistType) < 0)
-	return;
-    if(PyType_Ready(&LinkType) < 0)
-	return;
-    if(PyType_Ready(&PlaylistType) < 0)
-	return;
-    if(PyType_Ready(&PlaylistContainerType) < 0)
-	return;
-    if(PyType_Ready(&ResultsType) < 0)
-	return;
-    if(PyType_Ready(&TrackType) < 0)
-	return;
-    if(PyType_Ready(&ImageType) < 0)
-	return;
+    if (PyType_Ready(&SessionType) < 0)
+        return;
+    if (PyType_Ready(&ArtistType) < 0)
+        return;
+    if (PyType_Ready(&ArtistBrowserType) < 0)
+        return;
+    if (PyType_Ready(&LinkType) < 0)
+        return;
+    if (PyType_Ready(&PlaylistType) < 0)
+        return;
+    if (PyType_Ready(&PlaylistContainerType) < 0)
+        return;
+    if (PyType_Ready(&ResultsType) < 0)
+        return;
+    if (PyType_Ready(&TrackType) < 0)
+        return;
+    if (PyType_Ready(&ImageType) < 0)
+        return;
 
     m = Py_InitModule("_spotify", module_methods);
-    if(m == NULL)
+    if (m == NULL)
         return;
 
     PyObject *spotify = PyImport_ImportModule("spotify");
     PyObject *d = PyModule_GetDict(spotify);
     PyObject *s = PyString_FromString("SpotifyError");
+
     SpotifyError = PyDict_GetItem(d, s);
     Py_INCREF(SpotifyError);
 
@@ -72,9 +79,12 @@ PyMODINIT_FUNC init_spotify(void) {
     Py_INCREF(SpotifyApiVersion);
     PyModule_AddObject(m, "api_version", SpotifyApiVersion);
     album_init(m);
+    albumbrowser_init(m);
     artist_init(m);
+    artistbrowser_init(m);
     link_init(m);
     playlist_init(m);
+    playlistcontainer_init(m);
     session_init(m);
     search_init(m);
     track_init(m);
